@@ -37,8 +37,15 @@ class CestatsRun(BiobbObject):
             * **cumulative** (*bool*) - (False) Computes the cumulative average time series data over the course of the trajectory.
             * **fix_remd** (*str*) - ("") This option will trigger cestats to reassemble the titration data into pH-specific ensembles. This is an exclusive mode of the program, no other analyses will be done.
             * **conditional** (*str*) - ("") Evaluates conditional probabilities. CONDITIONAL should be a string of the format: <resid>:<state>,<resid>:<state>,... or <resid>:PROT,<resid>:DEPROT,... or <resid>:<state1>;<state2>,<resid>:PROT,... where <resid> is the residue number in the prmtop and <state> is either the state number or -p-rotonated or -d-eprotonated, case-insensitive.
+            * **binary_path** (*str*) - ("cestats") Path to the cestats executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
+            * **container_path** (*str*) - (None) Container path definition.
+            * **container_image** (*str*) - ('afandiadib/ambertools:serial') Container image definition.
+            * **container_volume_path** (*str*) - ('/tmp') Container volume path definition.
+            * **container_working_dir** (*str*) - (None) Container working directory definition.
+            * **container_user_id** (*str*) - (None) Container user_id definition.
+            * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
 
     Examples:
         This is a use example of how to use the building block from Python::
@@ -70,6 +77,7 @@ class CestatsRun(BiobbObject):
 
         # Call parent class constructor
         super().__init__(properties)
+        self.locals_var_dict = locals().copy()
 
         # Input/Output files
         self.io_dict = {
@@ -96,9 +104,11 @@ class CestatsRun(BiobbObject):
         self.cumulative = properties.get('cumulative', False)
         self.fix_remd = properties.get('fix_remd', "")
         self.conditional = properties.get('conditional', "")
+        self.binary_path = properties.get('binary_path', 'cestats')
 
         # Check the properties
         self.check_properties(properties)
+        self.check_arguments()
 
     def check_data_params(self, out_log, err_log):
         """ Checks input/output paths correctness """
@@ -128,35 +138,35 @@ class CestatsRun(BiobbObject):
 
         # Command line
         # cphstats -i 4LYT.equil.cpin 0/4LYT.md1.cpout -o pH0_calcpka.dat --population pH0_populations.dat
-        self.cmd = ['cestats',
+        self.cmd = [self.binary_path,
                '-O',
-               '-i', self.io_dict['in']['input_cein_path'],
-               '-o', self.io_dict['out']['output_dat_path'],
-               self.io_dict['in']['input_ceout_path']
+               '-i', self.stage_io_dict['in']['input_cein_path'],
+               '-o', self.stage_io_dict['out']['output_dat_path'],
+               self.stage_io_dict['in']['input_ceout_path']
                ]
 
         if self.io_dict['out']['output_population_path']:
             self.cmd.append('--population ')
-            self.cmd.append(self.io_dict['out']['output_population_path'])
+            self.cmd.append(self.stage_io_dict['out']['output_population_path'])
 
         if self.io_dict['out']['output_chunk_path']:
             self.cmd.append('--chunk-out ')
-            self.cmd.append(self.io_dict['out']['output_chunk_path'])
+            self.cmd.append(self.stage_io_dict['out']['output_chunk_path'])
             if self.chunk_window:
                 self.cmd.append('--chunk')
                 self.cmd.append(str(self.chunk_window))
 
         if self.io_dict['out']['output_cumulative_path']:
             self.cmd.append('--cumulative-out ')
-            self.cmd.append(self.io_dict['out']['output_cumulative_path'])
+            self.cmd.append(self.stage_io_dict['out']['output_cumulative_path'])
 
         if self.io_dict['out']['output_conditional_path']:
             self.cmd.append('--conditional-output ')
-            self.cmd.append(self.io_dict['out']['output_conditional_path'])
+            self.cmd.append(self.stage_io_dict['out']['output_conditional_path'])
 
         if self.io_dict['out']['output_chunk_conditional_path']:
             self.cmd.append('--chunk-conditional ')
-            self.cmd.append(self.io_dict['out']['output_chunk_conditional_path'])
+            self.cmd.append(self.stage_io_dict['out']['output_chunk_conditional_path'])
 
         if self.verbose:
             self.cmd.append('-v 1')
@@ -199,6 +209,14 @@ class CestatsRun(BiobbObject):
         # Copy files to host
         self.copy_to_host()
 
+        # Remove temporary file(s)
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir")
+        ])
+        self.remove_tmp_files()
+
+        self.check_arguments(output_files_created=True, raise_exception=False)
+
         return self.return_code
 
 def cestats_run(input_cein_path: str, input_ceout_path: str,
