@@ -22,8 +22,15 @@ class LeapBuildLinearStructure(BiobbObject):
             * **sequence** (*str*) - ("ALA GLY SER PRO ARG ALA PRO GLY") Aminoacid sequence to convert to a linear 3D structure. Aminoacids should be written in 3-letter code, with a blank space between them.
             * **forcefield** (*list*) - (["protein.ff14SB","DNA.bsc1","gaff"]) Forcefield to be used for the structure generation. Values: protein.ff14SB, protein.ff19SB, DNA.bsc1, DNA.OL15, RNA.OL3, gaff.
             * **build_library** (*bool*) - (False) Generate AMBER lib file for the structure.
+            * **binary_path** (*str*) - ("tleap") Path to the tleap executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
+            * **container_path** (*str*) - (None) Container path definition.
+            * **container_image** (*str*) - ('afandiadib/ambertools:serial') Container image definition.
+            * **container_volume_path** (*str*) - ('/tmp') Container volume path definition.
+            * **container_working_dir** (*str*) - (None) Container working directory definition.
+            * **container_user_id** (*str*) - (None) Container user_id definition.
+            * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
 
     Examples:
         This is a use example of how to use the building block from Python::
@@ -54,9 +61,11 @@ class LeapBuildLinearStructure(BiobbObject):
 
         # Call parent class constructor
         super().__init__(properties)
+        self.locals_var_dict = locals().copy()
 
         # Input/Output files
         self.io_dict = {
+            'in': {},
             'out': { 'output_pdb_path': output_pdb_path }
         }
 
@@ -65,9 +74,11 @@ class LeapBuildLinearStructure(BiobbObject):
         self.sequence = properties.get('sequence', "ALA GLY SER PRO ARG ALA PRO GLY")
         self.forcefield = properties.get('forcefield', ["protein.ff14SB","DNA.bsc1","gaff"])
         self.build_library = properties.get('build_library', False)
+        self.binary_path = properties.get('binary_path', 'tleap')
 
         # Check the properties
         self.check_properties(properties)
+        self.check_arguments()
 
     def check_data_params(self, out_log, err_log):
         """ Checks input/output paths correctness """
@@ -86,16 +97,23 @@ class LeapBuildLinearStructure(BiobbObject):
         if self.check_restart(): return 0
         self.stage_files()
 
-        # Creating temporary folder
-        self.tmp_folder = fu.create_unique_dir()
-        fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)
-
         # create .in file
         #TC5b = sequence { NASN LEU TYR ILE GLN TRP LEU LYS ASP GLY GLY PRO SER SER GLY ARG PRO PRO PRO CSER }
         #savepdb TC5b TC5b_linear.pdb
         #quit
 
-        instructions_file = str(PurePath(self.tmp_folder).joinpath("leap.in"))
+        # Creating temporary folder & Leap configuration (instructions) file
+        if self.container_path:
+            instructions_file = str(PurePath(self.stage_io_dict['unique_dir']).joinpath("leap.in"))
+            instructions_file_path = str(PurePath(self.container_volume_path).joinpath("leap.in"))
+            self.tmp_folder = None
+        else:
+            self.tmp_folder = fu.create_unique_dir()
+            instructions_file = str(PurePath(self.tmp_folder).joinpath("leap.in"))
+            fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)
+            instructions_file_path = instructions_file
+
+        #instructions_file = str(PurePath(self.tmp_folder).joinpath("leap.in"))
         with open(instructions_file, 'w') as leapin:
 
                 # Forcefields loaded from input forcefield property
@@ -103,12 +121,12 @@ class LeapBuildLinearStructure(BiobbObject):
                     leapin.write("source leaprc.{}\n".format(t))
 
                 leapin.write("struct = sequence {" + self.sequence + " } \n")
-                leapin.write("savepdb struct " + self.io_dict['out']['output_pdb_path'] + "\n")
+                leapin.write("savepdb struct " + self.stage_io_dict['out']['output_pdb_path'] + "\n")
                 leapin.write("quit \n");
 
         # Command line
-        self.cmd = ['tleap ',
-               '-f', instructions_file
+        self.cmd = [self.binary_path,
+               '-f', instructions_file_path
                ]
 
         # Run Biobb block
@@ -118,10 +136,14 @@ class LeapBuildLinearStructure(BiobbObject):
         self.copy_to_host()
 
         # remove temporary folder(s)
-        if self.remove_tmp:
-            self.tmp_files.append(self.tmp_folder)
-            self.tmp_files.append("leap.log")
-            self.remove_tmp_files()
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir"),
+            self.tmp_folder,
+            "leap.log"
+        ])
+        self.remove_tmp_files()
+
+        self.check_arguments(output_files_created=True, raise_exception=False)
 
         return self.return_code
 
