@@ -38,8 +38,15 @@ class LeapSolvate(BiobbObject):
             * **negative_ions_type** (*str*) - ("Cl-") Type of additional negative ions to include in the system box. Values: Cl-.
             * **distance_to_molecule** (*float*) - ("8.0") Size for the MD system box -in Angstroms-, defined such as the minimum distance between any atom originally present in solute and the edge of the periodic box is given by this distance parameter.
             * **closeness** (*float*) - ("1.0") How close, in Å, solvent ATOMs may come to solute ATOMs.
+            * **binary_path** (*str*) - ("tleap") Path to the tleap executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
+            * **container_path** (*str*) - (None) Container path definition.
+            * **container_image** (*str*) - ('afandiadib/ambertools:serial') Container image definition.
+            * **container_volume_path** (*str*) - ('/tmp') Container volume path definition.
+            * **container_working_dir** (*str*) - (None) Container working directory definition.
+            * **container_user_id** (*str*) - (None) Container user_id definition.
+            * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
 
     Examples:
         This is a use example of how to use the building block from Python::
@@ -77,6 +84,7 @@ class LeapSolvate(BiobbObject):
 
         # Call parent class constructor
         super().__init__(properties)
+        self.locals_var_dict = locals().copy()
 
         # Input/Output files
         self.io_dict = {
@@ -114,9 +122,11 @@ class LeapSolvate(BiobbObject):
         self.negative_ions_type = properties.get('negative_ions_type', "Cl-")
         self.distance_to_molecule = properties.get('distance_to_molecule', 8.0)
         self.closeness = properties.get('closeness', 1.0)
+        self.binary_path = properties.get('binary_path', 'tleap')
 
         # Check the properties
         self.check_properties(properties)
+        self.check_arguments()
 
     def check_data_params(self, out_log, err_log):
         """ Checks input/output paths correctness """
@@ -144,13 +154,6 @@ class LeapSolvate(BiobbObject):
         if self.check_restart(): return 0
         self.stage_files()
 
-        # Creating temporary folder
-        self.tmp_folder = fu.create_unique_dir()
-        fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)
-
-        # Leap configuration (instructions) file
-        instructions_file = str(PurePath(self.tmp_folder).joinpath("leap.in"))
-
         box_command = "solvateOct"
         if self.box_type == "cubic":
             box_command = "solvateBox"
@@ -185,30 +188,41 @@ class LeapSolvate(BiobbObject):
         ligands_lib_list = []
         if self.io_dict['in']['input_lib_path'] is not None:
             if self.io_dict['in']['input_lib_path'].endswith('.zip'):
-                ligands_lib_list = fu.unzip_list(self.io_dict['in']['input_lib_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
+                ligands_lib_list = fu.unzip_list(self.stage_io_dict['in']['input_lib_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
             else:
-                ligands_lib_list.append(self.io_dict['in']['input_lib_path'])
+                ligands_lib_list.append(self.stage_io_dict['in']['input_lib_path'])
 
         ligands_frcmod_list = []
         if self.io_dict['in']['input_frcmod_path'] is not None:
             if self.io_dict['in']['input_frcmod_path'].endswith('.zip'):
-                ligands_frcmod_list = fu.unzip_list(self.io_dict['in']['input_frcmod_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
+                ligands_frcmod_list = fu.unzip_list(self.stage_io_dict['in']['input_frcmod_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
             else:
-                ligands_frcmod_list.append(self.io_dict['in']['input_frcmod_path'])
+                ligands_frcmod_list.append(self.stage_io_dict['in']['input_frcmod_path'])
 
         amber_params_list = []
         if self.io_dict['in']['input_params_path'] is not None:
             if self.io_dict['in']['input_params_path'].endswith('.zip'):
-                amber_params_list = fu.unzip_list(self.io_dict['in']['input_params_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
+                amber_params_list = fu.unzip_list(self.stage_io_dict['in']['input_params_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
             else:
-                amber_params_list.append(self.io_dict['in']['input_params_path'])
+                amber_params_list.append(self.stage_io_dict['in']['input_params_path'])
 
         leap_source_list = []
         if self.io_dict['in']['input_source_path'] is not None:
             if self.io_dict['in']['input_source_path'].endswith('.zip'):
-                leap_source_list = fu.unzip_list(self.io_dict['in']['input_source_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
+                leap_source_list = fu.unzip_list(self.stage_io_dict['in']['input_source_path'], dest_dir=self.tmp_folder, out_log=self.out_log)
             else:
-                leap_source_list.append(self.io_dict['in']['input_source_path'])
+                leap_source_list.append(self.stage_io_dict['in']['input_source_path'])
+
+        # Creating temporary folder & Leap configuration (instructions) file
+        if self.container_path:
+            instructions_file = str(PurePath(self.stage_io_dict['unique_dir']).joinpath("leap.in"))
+            instructions_file_path = str(PurePath(self.container_volume_path).joinpath("leap.in"))
+            self.tmp_folder = None
+        else:
+            self.tmp_folder = fu.create_unique_dir()
+            instructions_file = str(PurePath(self.tmp_folder).joinpath("leap.in"))
+            fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)
+            instructions_file_path = instructions_file
 
         with open(instructions_file, 'w') as leapin:
                 # Forcefields loaded by default:
@@ -245,7 +259,7 @@ class LeapSolvate(BiobbObject):
                     leapin.write("loadamberparams " + amber_frcmod + "\n")
 
                 # Loading PDB file
-                leapin.write("mol = loadpdb " + self.io_dict['in']['input_pdb_path'] + " \n")
+                leapin.write("mol = loadpdb " + self.stage_io_dict['in']['input_pdb_path'] + " \n")
 
                 # Generating box + adding water molecules
                 leapin.write(box_command + " mol " + self.water_type + " " + str(self.distance_to_molecule) + " " + str(self.closeness))
@@ -255,13 +269,13 @@ class LeapSolvate(BiobbObject):
                 leapin.write(ions_command)
 
                 # Saving output PDB file, coordinates and topology
-                leapin.write("savepdb mol " + self.io_dict['out']['output_pdb_path'] + " \n")
-                leapin.write("saveAmberParm mol " + self.io_dict['out']['output_top_path'] + " " + self.io_dict['out']['output_crd_path'] + "\n")
+                leapin.write("savepdb mol " + self.stage_io_dict['out']['output_pdb_path'] + " \n")
+                leapin.write("saveAmberParm mol " + self.stage_io_dict['out']['output_top_path'] + " " + self.stage_io_dict['out']['output_crd_path'] + "\n")
                 leapin.write("quit \n");
 
         # Command line
-        self.cmd = ['tleap ',
-               '-f', instructions_file
+        self.cmd = [self.binary_path,
+               '-f', instructions_file_path
                ]
 
         # Run Biobb block
@@ -285,10 +299,14 @@ class LeapSolvate(BiobbObject):
             f.write(octbox + content)
 
         # remove temporary folder(s)
-        if self.remove_tmp:
-            self.tmp_files.append(self.tmp_folder)
-            self.tmp_files.append("leap.log")
-            self.remove_tmp_files()
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir"),
+            self.tmp_folder,
+            "leap.log"
+        ])
+        self.remove_tmp_files()
+
+        self.check_arguments(output_files_created=True, raise_exception=False)
 
         return self.return_code
 
