@@ -24,8 +24,15 @@ class ParmedCpinUtil(BiobbObject):
             * **resnames** (*str*) - ("None") Residue names to include in CPIN file. Values: AS4, GL4, HIP, CYS, LYS, TYR.
             * **igb** (*int*) - (2) Generalized Born model which you intend to use to evaluate dynamics or protonation state swaps. Values: 1, 2, 5, 7, 8.
             * **system** (*str*) - ("Unknown") Name of system to titrate.
+            * **binary_path** (*str*) - ("cpinutil.py") Path to the cpinutil.py executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
+            * **container_path** (*str*) - (None) Container path definition.
+            * **container_image** (*str*) - ('afandiadib/ambertools:serial') Container image definition.
+            * **container_volume_path** (*str*) - ('/tmp') Container volume path definition.
+            * **container_working_dir** (*str*) - (None) Container working directory definition.
+            * **container_user_id** (*str*) - (None) Container user_id definition.
+            * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
 
     Examples:
         This is a use example of how to use the building block from Python::
@@ -59,6 +66,7 @@ class ParmedCpinUtil(BiobbObject):
 
         # Call parent class constructor
         super().__init__(properties)
+        self.locals_var_dict = locals().copy()
 
         # Input/Output files
         self.io_dict = {
@@ -72,9 +80,11 @@ class ParmedCpinUtil(BiobbObject):
         self.resnames = properties.get('resnames')
         self.igb = properties.get('igb', 2)
         self.system = properties.get('system', "Unknown")
+        self.binary_path = properties.get('binary_path', 'cpinutil.py')
 
         # Check the properties
         self.check_properties(properties)
+        self.check_arguments()
 
     def check_data_params(self, out_log, err_log):
         """ Checks input/output paths correctness """
@@ -106,9 +116,9 @@ class ParmedCpinUtil(BiobbObject):
 
         fu.log('Creating command line with instructions and required arguments', self.out_log, self.global_log)
 
-        self.cmd = ['cpinutil.py',
-               '-p', self.io_dict['in']['input_top_path'],
-               '-o', self.io_dict['out']['output_cpin_path']
+        self.cmd = [self.binary_path,
+               '-p', self.stage_io_dict['in']['input_top_path'],
+               '-o', self.stage_io_dict['out']['output_cpin_path']
                ]
 
         if self.igb:
@@ -125,7 +135,7 @@ class ParmedCpinUtil(BiobbObject):
 
         if self.io_dict["out"]["output_top_path"]:
             self.cmd.append('-op')
-            self.cmd.append(self.io_dict["out"]["output_top_path"])
+            self.cmd.append(self.stage_io_dict["out"]["output_top_path"])
 
         # Run Biobb block
         self.run_biobb()
@@ -134,9 +144,13 @@ class ParmedCpinUtil(BiobbObject):
         self.copy_to_host()
 
         # remove temporary folder(s)
-        if self.remove_tmp:
-            self.tmp_files.append(self.tmp_folder)
-            self.remove_tmp_files()
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir"),
+            self.tmp_folder
+        ])
+        self.remove_tmp_files()
+
+        self.check_arguments(output_files_created=True, raise_exception=False)
 
         return self.return_code
 
