@@ -20,8 +20,15 @@ class ParmedHMassRepartition(BiobbObject):
         input_top_path (str): Input AMBER topology file. File type: input. `Sample file <https://github.com/bioexcel/biobb_amber/raw/master/biobb_amber/test/data/parmed/input.hmass.prmtop>`_. Accepted formats: top (edam:format_3881), parmtop (edam:format_3881), prmtop (edam:format_3881).
         output_top_path (str): Output topology file (AMBER ParmTop). File type: output. `Sample file <https://github.com/bioexcel/biobb_amber/raw/master/biobb_amber/test/reference/parmed/output.hmass.prmtop>`_. Accepted formats: top (edam:format_3881), parmtop (edam:format_3881), prmtop (edam:format_3881).
         properties (dic - Python dictionary object containing the tool parameters, not input/output files):
+            * **binary_path** (*str*) - ("parmed") Path to the parmed executable binary.
             * **remove_tmp** (*bool*) - (True) [WF property] Remove temporal files.
             * **restart** (*bool*) - (False) [WF property] Do not execute if output files exist.
+            * **container_path** (*str*) - (None) Container path definition.
+            * **container_image** (*str*) - ('afandiadib/ambertools:serial') Container image definition.
+            * **container_volume_path** (*str*) - ('/tmp') Container volume path definition.
+            * **container_working_dir** (*str*) - (None) Container working directory definition.
+            * **container_user_id** (*str*) - (None) Container user_id definition.
+            * **container_shell_path** (*str*) - ('/bin/bash') Path to default shell inside the container.
 
     Examples:
         This is a use example of how to use the building block from Python::
@@ -47,6 +54,7 @@ class ParmedHMassRepartition(BiobbObject):
 
         # Call parent class constructor
         super().__init__(properties)
+        self.locals_var_dict = locals().copy()
 
         # Input/Output files
         self.io_dict = {
@@ -56,9 +64,11 @@ class ParmedHMassRepartition(BiobbObject):
 
         # Properties specific for BB
         self.properties = properties
+        self.binary_path = properties.get('binary_path', 'parmed')
 
         # Check the properties
         self.check_properties(properties)
+        self.check_arguments()
 
     def check_data_params(self, out_log, err_log):
         """ Checks input/output paths correctness """
@@ -80,20 +90,24 @@ class ParmedHMassRepartition(BiobbObject):
         if self.check_restart(): return 0
         self.stage_files()
 
-        # Creating temporary folder
-        self.tmp_folder = fu.create_unique_dir()
-        fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)
-
-        # Parmed configuration (instructions) file
-        instructions_file = str(PurePath(self.tmp_folder).joinpath("parmed.in"))
+        # Creating temporary folder & Parmed configuration (instructions) file
+        if self.container_path:
+            instructions_file = str(PurePath(self.stage_io_dict['unique_dir']).joinpath("parmed.in"))
+            instructions_file_path = str(PurePath(self.container_volume_path).joinpath("parmed.in"))
+            self.tmp_folder = None
+        else:
+            self.tmp_folder = fu.create_unique_dir()
+            instructions_file = str(PurePath(self.tmp_folder).joinpath("parmed.in"))
+            fu.log('Creating %s temporary folder' % self.tmp_folder, self.out_log)
+            instructions_file_path = instructions_file
 
         with open(instructions_file, 'w') as parmedin:
             parmedin.write("hmassrepartition\n")
-            parmedin.write("outparm " + self.io_dict['out']['output_top_path'] + "\n")
+            parmedin.write("outparm " + self.stage_io_dict['out']['output_top_path'] + "\n")
 
-        self.cmd = ['parmed',
-               '-p', self.io_dict['in']['input_top_path'],
-               '-i', instructions_file,
+        self.cmd = [self.binary_path,
+               '-p', self.stage_io_dict['in']['input_top_path'],
+               '-i', instructions_file_path,
                '-O' # Overwrite output files
                ]
 
@@ -104,9 +118,13 @@ class ParmedHMassRepartition(BiobbObject):
         self.copy_to_host()
 
         # remove temporary folder(s)
-        if self.remove_tmp:
-            self.tmp_files.append(self.tmp_folder)
-            self.remove_tmp_files()
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir"),
+            self.tmp_folder
+        ])
+        self.remove_tmp_files()
+
+        self.check_arguments(output_files_created=True, raise_exception=False)
 
         return self.return_code
 
