@@ -30,7 +30,7 @@ class PmemdMDRun(BiobbObject):
         output_mdinfo_path (str) (Optional): Output MD info. File type: output. `Sample file <https://github.com/bioexcel/biobb_amber/raw/master/biobb_amber/test/reference/pmemd/sander.mdinfo>`_. Accepted formats: mdinfo (edam:format_2330).
         properties (dict - Python dictionary object containing the tool parameters, not input/output files):
             * **mdin** (*dict*) - ({}) pmemd MD run options specification. (Used if *input_mdin_path* is None)
-            * **pmemd_path** (*str*) - ("pmemd") pmemd binary path to be used.
+            * **binary_path** (*str*) - ("pmemd") pmemd binary path to be used.
             * **simulation_type** (*str*) - ("minimization") Default options for the mdin file. Each creates a different mdin file. Values: `minimization <https://biobb-amber.readthedocs.io/en/latest/_static/mdin/minimization.mdin>`_ (Runs an energy minimization), `min_vacuo <https://biobb-amber.readthedocs.io/en/latest/_static/mdin/min_vacuo.mdin>`_ (Runs an energy minimization in vacuo), `NVT <https://biobb-amber.readthedocs.io/en/latest/_static/mdin/NVT.mdin>`_ (Runs an NVT equilibration), `npt <https://biobb-amber.readthedocs.io/en/latest/_static/mdin/NPT.mdin>`_ (Runs an NPT equilibration), `free <https://biobb-amber.readthedocs.io/en/latest/_static/mdin/free.mdin>`_ (Runs a MD simulation).
             * **mpi_bin** (*str*) - (None) Path to the MPI runner. Usually "mpirun" or "srun".
             * **mpi_np** (*int*) - (0) [0~1000|1] Number of MPI processes. Usually an integer bigger than 1.
@@ -74,6 +74,7 @@ class PmemdMDRun(BiobbObject):
 
         # Call parent class constructor
         super().__init__(properties)
+        self.locals_var_dict = locals().copy()
 
         # Input/Output files
         self.io_dict = {
@@ -93,7 +94,7 @@ class PmemdMDRun(BiobbObject):
         # Properties specific for BB
         self.properties = properties
         self.simulation_type = properties.get('simulation_type', "minimization")
-        self.pmemd_path = properties.get('pmemd_path', "pmemd")
+        self.binary_path = properties.get('binary_path', "pmemd")
         self.mdin = {k: str(v) for k, v in properties.get('mdin', dict()).items()}
 
         # Properties for MPI
@@ -103,6 +104,7 @@ class PmemdMDRun(BiobbObject):
 
         # Check the properties
         self.check_properties(properties)
+        self.check_arguments()
 
     def check_data_params(self, out_log, err_log):
         """ Checks input/output paths correctness """
@@ -293,7 +295,7 @@ class PmemdMDRun(BiobbObject):
 
         # Command line
         # pmemd -O -i mdin/min.mdin -p $1.cpH.prmtop -c ph$i/$1.inpcrd -r ph$i/$1.min.rst7 -o ph$i/$1.min.o
-        self.cmd = [self.pmemd_path,
+        self.cmd = [self.binary_path,
                '-O',
                '-i', self.output_mdin_path,
                '-p', self.io_dict['in']['input_top_path'],
@@ -331,7 +333,7 @@ class PmemdMDRun(BiobbObject):
                 mpi_cmd.append(str(self.mpi_np))
             if self.mpi_flags:
                 mpi_cmd.extend(self.mpi_flags)
-            self.cmd = mpi_cmd + cmd
+            self.cmd = mpi_cmd + self.cmd
 
         # Run Biobb block
         self.run_biobb()
@@ -340,10 +342,14 @@ class PmemdMDRun(BiobbObject):
         self.copy_to_host()
 
         # remove temporary folder(s)
-        if self.remove_tmp:
-            self.tmp_files.append(self.tmp_folder)
-            self.tmp_files.append("mdinfo")
-            self.remove_tmp_files()
+        self.tmp_files.extend([
+            self.stage_io_dict.get("unique_dir"),
+            self.tmp_folder,
+            "mdinfo"
+        ])
+        self.remove_tmp_files()
+
+        self.check_arguments(output_files_created=True, raise_exception=False)
 
         return self.return_code
 
